@@ -5,7 +5,7 @@ from lobotomy._cli import _definitions
 from lobotomy._cli import _parsing
 
 
-def run(arguments: typing.List[str] = None) -> '_definitions.ExecutionResult':
+def run(arguments: typing.List[str] = None) -> "_definitions.ExecutionResult":
     """
     Executes a cli command with the given arguments, or sys.argv if no
     explicit arguments were specified.
@@ -14,7 +14,7 @@ def run(arguments: typing.List[str] = None) -> '_definitions.ExecutionResult':
     context = _definitions.CliContext(args)
 
     commands = {
-        'add': _adder.run,
+        "add": _adder.run,
     }
 
     return commands[args.command](context)
